Class: Emailguard::BillingApi

Inherits:
Object
  • Object
show all
Defined in:
lib/emailguard_sdk/api/billing_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ BillingApi

Returns a new instance of BillingApi.



19
20
21
# File 'lib/emailguard_sdk/api/billing_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/emailguard_sdk/api/billing_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#api_v1_team_billing_usage_get(opts = {}) ⇒ BillingUsageResponse

Get billing usage Returns metered feature usage for the team's billing period. Defaults to the current period; use range=previous or range=custom with start and end to query other windows.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :range (String)

    Period selector: current, previous, or custom

  • :start (String)

    Custom range start (RFC3339 or YYYY-MM-DD); required when range=custom

  • :_end (String)

    Custom range end (RFC3339 or YYYY-MM-DD); required when range=custom

Returns:



29
30
31
32
# File 'lib/emailguard_sdk/api/billing_api.rb', line 29

def api_v1_team_billing_usage_get(opts = {})
  data, _status_code, _headers = api_v1_team_billing_usage_get_with_http_info(opts)
  data
end

#api_v1_team_billing_usage_get_with_http_info(opts = {}) ⇒ Array<(BillingUsageResponse, Integer, Hash)>

Get billing usage Returns metered feature usage for the team's billing period. Defaults to the current period; use `range=previous` or `range=custom` with `start` and `end` to query other windows.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :range (String)

    Period selector: current, previous, or custom

  • :start (String)

    Custom range start (RFC3339 or YYYY-MM-DD); required when range=custom

  • :_end (String)

    Custom range end (RFC3339 or YYYY-MM-DD); required when range=custom

Returns:

  • (Array<(BillingUsageResponse, Integer, Hash)>)

    BillingUsageResponse data, response status code and response headers



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/emailguard_sdk/api/billing_api.rb', line 41

def api_v1_team_billing_usage_get_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: BillingApi.api_v1_team_billing_usage_get ...'
  end
  allowable_values = ["current", "previous", "custom"]
  if @api_client.config.client_side_validation && opts[:'range'] && !allowable_values.include?(opts[:'range'])
    fail ArgumentError, "invalid value for \"range\", must be one of #{allowable_values}"
  end
  # resource path
  local_var_path = '/api/v1/team/billing/usage'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'range'] = opts[:'range'] if !opts[:'range'].nil?
  query_params[:'start'] = opts[:'start'] if !opts[:'start'].nil?
  query_params[:'end'] = opts[:'_end'] if !opts[:'_end'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'BillingUsageResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"BillingApi.api_v1_team_billing_usage_get",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: BillingApi#api_v1_team_billing_usage_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end