Class: Emailguard::EmailApi
- Inherits:
-
Object
- Object
- Emailguard::EmailApi
- Defined in:
- lib/emailguard_sdk/api/email_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#api_v1_emails_detect_get(email, opts = {}) ⇒ EmailDetectResponse
Detect email characteristics Analyzes an email for syntax, normalization, typo suggestions, role/public/relay/disposable signals.
-
#api_v1_emails_detect_get_with_http_info(email, opts = {}) ⇒ Array<(EmailDetectResponse, Integer, Hash)>
Detect email characteristics Analyzes an email for syntax, normalization, typo suggestions, role/public/relay/disposable signals.
-
#initialize(api_client = ApiClient.default) ⇒ EmailApi
constructor
A new instance of EmailApi.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/emailguard_sdk/api/email_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#api_v1_emails_detect_get(email, opts = {}) ⇒ EmailDetectResponse
Detect email characteristics Analyzes an email for syntax, normalization, typo suggestions, role/public/relay/disposable signals. Invalid TLDs can return suggested_email and suggested_domain while syntax_validation remains false.
27 28 29 30 |
# File 'lib/emailguard_sdk/api/email_api.rb', line 27 def api_v1_emails_detect_get(email, opts = {}) data, _status_code, _headers = api_v1_emails_detect_get_with_http_info(email, opts) data end |
#api_v1_emails_detect_get_with_http_info(email, opts = {}) ⇒ Array<(EmailDetectResponse, Integer, Hash)>
Detect email characteristics Analyzes an email for syntax, normalization, typo suggestions, role/public/relay/disposable signals. Invalid TLDs can return suggested_email and suggested_domain while syntax_validation remains false.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/emailguard_sdk/api/email_api.rb', line 37 def api_v1_emails_detect_get_with_http_info(email, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EmailApi.api_v1_emails_detect_get ...' end # verify the required parameter 'email' is set if @api_client.config.client_side_validation && email.nil? fail ArgumentError, "Missing the required parameter 'email' when calling EmailApi.api_v1_emails_detect_get" end # resource path local_var_path = '/api/v1/emails/detect' # query parameters query_params = opts[:query_params] || {} query_params[:'email'] = email # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'EmailDetectResponse' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"EmailApi.api_v1_emails_detect_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EmailApi#api_v1_emails_detect_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |