Class: Emailguard::EventsApi
- Inherits:
-
Object
- Object
- Emailguard::EventsApi
- Defined in:
- lib/emailguard_sdk/api/events_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#api_v1_team_notifications_events_get(opts = {}) ⇒ GetNotificationEventsResponse
List notification events Returns recent notification delivery events for polling integrations.
-
#api_v1_team_notifications_events_get_with_http_info(opts = {}) ⇒ Array<(GetNotificationEventsResponse, Integer, Hash)>
List notification events Returns recent notification delivery events for polling integrations.
-
#initialize(api_client = ApiClient.default) ⇒ EventsApi
constructor
A new instance of EventsApi.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/emailguard_sdk/api/events_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#api_v1_team_notifications_events_get(opts = {}) ⇒ GetNotificationEventsResponse
List notification events Returns recent notification delivery events for polling integrations. Use this to inspect what was sent and when without configuring a webhook receiver.
26 27 28 29 |
# File 'lib/emailguard_sdk/api/events_api.rb', line 26 def api_v1_team_notifications_events_get(opts = {}) data, _status_code, _headers = api_v1_team_notifications_events_get_with_http_info(opts) data end |
#api_v1_team_notifications_events_get_with_http_info(opts = {}) ⇒ Array<(GetNotificationEventsResponse, Integer, Hash)>
List notification events Returns recent notification delivery events for polling integrations. Use this to inspect what was sent and when without configuring a webhook receiver.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/emailguard_sdk/api/events_api.rb', line 35 def api_v1_team_notifications_events_get_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EventsApi.api_v1_team_notifications_events_get ...' end # resource path local_var_path = '/api/v1/team/notifications/events' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetNotificationEventsResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"EventsApi.api_v1_team_notifications_events_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EventsApi#api_v1_team_notifications_events_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |