Class: Emailguard::PublicTeamMemberResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Emailguard::PublicTeamMemberResponse
- Defined in:
- lib/emailguard_sdk/models/public_team_member_response.rb
Instance Attribute Summary collapse
-
#created_at ⇒ Object
When the member joined the team (RFC3339).
-
#email ⇒ Object
Member login email.
-
#emoji ⇒ Object
User profile emoji.
-
#first_name ⇒ Object
Member given name.
-
#id ⇒ Object
Team membership record ID.
-
#last_name ⇒ Object
Member family name.
-
#notes ⇒ Object
Internal notes stored on the membership.
-
#role ⇒ Object
Team role (for example Owner, Admin, Member).
-
#user_id ⇒ Object
User account ID for this member.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PublicTeamMemberResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PublicTeamMemberResponse
Initializes the object
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/emailguard_sdk/models/public_team_member_response.rb', line 93 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Emailguard::PublicTeamMemberResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Emailguard::PublicTeamMemberResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'email') self.email = attributes[:'email'] else self.email = nil end if attributes.key?(:'emoji') self.emoji = attributes[:'emoji'] end if attributes.key?(:'first_name') self.first_name = attributes[:'first_name'] else self.first_name = nil end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'last_name') self.last_name = attributes[:'last_name'] else self.last_name = nil end if attributes.key?(:'notes') self.notes = attributes[:'notes'] end if attributes.key?(:'role') self.role = attributes[:'role'] else self.role = nil end if attributes.key?(:'user_id') self.user_id = attributes[:'user_id'] else self.user_id = nil end end |
Instance Attribute Details
#created_at ⇒ Object
When the member joined the team (RFC3339).
19 20 21 |
# File 'lib/emailguard_sdk/models/public_team_member_response.rb', line 19 def created_at @created_at end |
#email ⇒ Object
Member login email.
22 23 24 |
# File 'lib/emailguard_sdk/models/public_team_member_response.rb', line 22 def email @email end |
#emoji ⇒ Object
User profile emoji.
25 26 27 |
# File 'lib/emailguard_sdk/models/public_team_member_response.rb', line 25 def emoji @emoji end |
#first_name ⇒ Object
Member given name.
28 29 30 |
# File 'lib/emailguard_sdk/models/public_team_member_response.rb', line 28 def first_name @first_name end |
#id ⇒ Object
Team membership record ID.
31 32 33 |
# File 'lib/emailguard_sdk/models/public_team_member_response.rb', line 31 def id @id end |
#last_name ⇒ Object
Member family name.
34 35 36 |
# File 'lib/emailguard_sdk/models/public_team_member_response.rb', line 34 def last_name @last_name end |
#notes ⇒ Object
Internal notes stored on the membership.
37 38 39 |
# File 'lib/emailguard_sdk/models/public_team_member_response.rb', line 37 def notes @notes end |
#role ⇒ Object
Team role (for example Owner, Admin, Member).
40 41 42 |
# File 'lib/emailguard_sdk/models/public_team_member_response.rb', line 40 def role @role end |
#user_id ⇒ Object
User account ID for this member.
43 44 45 |
# File 'lib/emailguard_sdk/models/public_team_member_response.rb', line 43 def user_id @user_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
61 62 63 |
# File 'lib/emailguard_sdk/models/public_team_member_response.rb', line 61 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
66 67 68 |
# File 'lib/emailguard_sdk/models/public_team_member_response.rb', line 66 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/emailguard_sdk/models/public_team_member_response.rb', line 46 def self.attribute_map { :'created_at' => :'created_at', :'email' => :'email', :'emoji' => :'emoji', :'first_name' => :'first_name', :'id' => :'id', :'last_name' => :'last_name', :'notes' => :'notes', :'role' => :'role', :'user_id' => :'user_id' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'lib/emailguard_sdk/models/public_team_member_response.rb', line 309 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
86 87 88 89 |
# File 'lib/emailguard_sdk/models/public_team_member_response.rb', line 86 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/emailguard_sdk/models/public_team_member_response.rb', line 71 def self.openapi_types { :'created_at' => :'String', :'email' => :'String', :'emoji' => :'String', :'first_name' => :'String', :'id' => :'String', :'last_name' => :'String', :'notes' => :'String', :'role' => :'String', :'user_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
280 281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/emailguard_sdk/models/public_team_member_response.rb', line 280 def ==(o) return true if self.equal?(o) self.class == o.class && created_at == o.created_at && email == o.email && emoji == o.emoji && first_name == o.first_name && id == o.id && last_name == o.last_name && notes == o.notes && role == o.role && user_id == o.user_id end |
#eql?(o) ⇒ Boolean
296 297 298 |
# File 'lib/emailguard_sdk/models/public_team_member_response.rb', line 296 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
302 303 304 |
# File 'lib/emailguard_sdk/models/public_team_member_response.rb', line 302 def hash [created_at, email, emoji, first_name, id, last_name, notes, role, user_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/emailguard_sdk/models/public_team_member_response.rb', line 160 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @email.nil? invalid_properties.push('invalid value for "email", email cannot be nil.') end if @first_name.nil? invalid_properties.push('invalid value for "first_name", first_name cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @last_name.nil? invalid_properties.push('invalid value for "last_name", last_name cannot be nil.') end if @role.nil? invalid_properties.push('invalid value for "role", role cannot be nil.') end if @user_id.nil? invalid_properties.push('invalid value for "user_id", user_id cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
331 332 333 334 335 336 337 338 339 340 341 342 343 |
# File 'lib/emailguard_sdk/models/public_team_member_response.rb', line 331 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/emailguard_sdk/models/public_team_member_response.rb', line 196 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @created_at.nil? return false if @email.nil? return false if @first_name.nil? return false if @id.nil? return false if @last_name.nil? return false if @role.nil? return false if @user_id.nil? true end |