Class: Emailguard::RulesApi

Inherits:
Object
  • Object
show all
Defined in:
lib/emailguard_sdk/api/rules_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ RulesApi

Returns a new instance of RulesApi.



19
20
21
# File 'lib/emailguard_sdk/api/rules_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/emailguard_sdk/api/rules_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#api_v1_team_notifications_rules_get(opts = {}) ⇒ GetNotificationRulesResponse

List notification rules Returns routing rules that map event types to one or more delivery channels. Each rule includes its enabled state and channel targets.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



26
27
28
29
# File 'lib/emailguard_sdk/api/rules_api.rb', line 26

def api_v1_team_notifications_rules_get(opts = {})
  data, _status_code, _headers = api_v1_team_notifications_rules_get_with_http_info(opts)
  data
end

#api_v1_team_notifications_rules_get_with_http_info(opts = {}) ⇒ Array<(GetNotificationRulesResponse, Integer, Hash)>

List notification rules Returns routing rules that map event types to one or more delivery channels. Each rule includes its enabled state and channel targets.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/emailguard_sdk/api/rules_api.rb', line 35

def api_v1_team_notifications_rules_get_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RulesApi.api_v1_team_notifications_rules_get ...'
  end
  # resource path
  local_var_path = '/api/v1/team/notifications/rules'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetNotificationRulesResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"RulesApi.api_v1_team_notifications_rules_get",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RulesApi#api_v1_team_notifications_rules_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#api_v1_team_notifications_rules_post(create_notification_rule_input, opts = {}) ⇒ IdDataResponse

Create notification rule Creates a rule that delivers matching events to the specified channels. At least one event type and one channel target are required.

Parameters:

  • create_notification_rule_input (CreateNotificationRuleInput)

    Rule name, event types, and channel targets

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



84
85
86
87
# File 'lib/emailguard_sdk/api/rules_api.rb', line 84

def api_v1_team_notifications_rules_post(create_notification_rule_input, opts = {})
  data, _status_code, _headers = api_v1_team_notifications_rules_post_with_http_info(create_notification_rule_input, opts)
  data
end

#api_v1_team_notifications_rules_post_with_http_info(create_notification_rule_input, opts = {}) ⇒ Array<(IdDataResponse, Integer, Hash)>

Create notification rule Creates a rule that delivers matching events to the specified channels. At least one event type and one channel target are required.

Parameters:

  • create_notification_rule_input (CreateNotificationRuleInput)

    Rule name, event types, and channel targets

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(IdDataResponse, Integer, Hash)>)

    IdDataResponse data, response status code and response headers



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'lib/emailguard_sdk/api/rules_api.rb', line 94

def api_v1_team_notifications_rules_post_with_http_info(create_notification_rule_input, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RulesApi.api_v1_team_notifications_rules_post ...'
  end
  # verify the required parameter 'create_notification_rule_input' is set
  if @api_client.config.client_side_validation && create_notification_rule_input.nil?
    fail ArgumentError, "Missing the required parameter 'create_notification_rule_input' when calling RulesApi.api_v1_team_notifications_rules_post"
  end
  # resource path
  local_var_path = '/api/v1/team/notifications/rules'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(create_notification_rule_input)

  # return_type
  return_type = opts[:debug_return_type] || 'IdDataResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"RulesApi.api_v1_team_notifications_rules_post",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RulesApi#api_v1_team_notifications_rules_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#api_v1_team_notifications_rules_rule_id_delete(rule_id, opts = {}) ⇒ MessageResponse

Delete notification rule Permanently deletes a routing rule and its channel assignments.

Parameters:

  • rule_id (String)

    UUID of the notification rule to delete

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



152
153
154
155
# File 'lib/emailguard_sdk/api/rules_api.rb', line 152

def api_v1_team_notifications_rules_rule_id_delete(rule_id, opts = {})
  data, _status_code, _headers = api_v1_team_notifications_rules_rule_id_delete_with_http_info(rule_id, opts)
  data
end

#api_v1_team_notifications_rules_rule_id_delete_with_http_info(rule_id, opts = {}) ⇒ Array<(MessageResponse, Integer, Hash)>

Delete notification rule Permanently deletes a routing rule and its channel assignments.

Parameters:

  • rule_id (String)

    UUID of the notification rule to delete

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(MessageResponse, Integer, Hash)>)

    MessageResponse data, response status code and response headers



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/emailguard_sdk/api/rules_api.rb', line 162

def api_v1_team_notifications_rules_rule_id_delete_with_http_info(rule_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RulesApi.api_v1_team_notifications_rules_rule_id_delete ...'
  end
  # verify the required parameter 'rule_id' is set
  if @api_client.config.client_side_validation && rule_id.nil?
    fail ArgumentError, "Missing the required parameter 'rule_id' when calling RulesApi.api_v1_team_notifications_rules_rule_id_delete"
  end
  # resource path
  local_var_path = '/api/v1/team/notifications/rules/{ruleId}'.sub('{ruleId}', CGI.escape(rule_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'MessageResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"RulesApi.api_v1_team_notifications_rules_rule_id_delete",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RulesApi#api_v1_team_notifications_rules_rule_id_delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#api_v1_team_notifications_rules_rule_id_put(rule_id, update_notification_rule_input, opts = {}) ⇒ MessageResponse

Update notification rule Updates a rule's name, description, event types, enabled flag, or channel targets. When channels is sent it replaces all existing targets.

Parameters:

  • rule_id (String)

    UUID of the notification rule to update

  • update_notification_rule_input (UpdateNotificationRuleInput)

    Fields to update on the rule

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



216
217
218
219
# File 'lib/emailguard_sdk/api/rules_api.rb', line 216

def api_v1_team_notifications_rules_rule_id_put(rule_id, update_notification_rule_input, opts = {})
  data, _status_code, _headers = api_v1_team_notifications_rules_rule_id_put_with_http_info(rule_id, update_notification_rule_input, opts)
  data
end

#api_v1_team_notifications_rules_rule_id_put_with_http_info(rule_id, update_notification_rule_input, opts = {}) ⇒ Array<(MessageResponse, Integer, Hash)>

Update notification rule Updates a rule's name, description, event types, enabled flag, or channel targets. When `channels` is sent it replaces all existing targets.

Parameters:

  • rule_id (String)

    UUID of the notification rule to update

  • update_notification_rule_input (UpdateNotificationRuleInput)

    Fields to update on the rule

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(MessageResponse, Integer, Hash)>)

    MessageResponse data, response status code and response headers



227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'lib/emailguard_sdk/api/rules_api.rb', line 227

def api_v1_team_notifications_rules_rule_id_put_with_http_info(rule_id, update_notification_rule_input, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RulesApi.api_v1_team_notifications_rules_rule_id_put ...'
  end
  # verify the required parameter 'rule_id' is set
  if @api_client.config.client_side_validation && rule_id.nil?
    fail ArgumentError, "Missing the required parameter 'rule_id' when calling RulesApi.api_v1_team_notifications_rules_rule_id_put"
  end
  # verify the required parameter 'update_notification_rule_input' is set
  if @api_client.config.client_side_validation && update_notification_rule_input.nil?
    fail ArgumentError, "Missing the required parameter 'update_notification_rule_input' when calling RulesApi.api_v1_team_notifications_rules_rule_id_put"
  end
  # resource path
  local_var_path = '/api/v1/team/notifications/rules/{ruleId}'.sub('{ruleId}', CGI.escape(rule_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(update_notification_rule_input)

  # return_type
  return_type = opts[:debug_return_type] || 'MessageResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"RulesApi.api_v1_team_notifications_rules_rule_id_put",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PUT, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RulesApi#api_v1_team_notifications_rules_rule_id_put\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end