Class: Emailguard::TeamsApi
- Inherits:
-
Object
- Object
- Emailguard::TeamsApi
- Defined in:
- lib/emailguard_sdk/api/teams_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#api_v1_team_get(opts = {}) ⇒ GetPublicTeamResponse
Get team Returns profile fields for the team associated with your API key.
-
#api_v1_team_get_with_http_info(opts = {}) ⇒ Array<(GetPublicTeamResponse, Integer, Hash)>
Get team Returns profile fields for the team associated with your API key.
-
#api_v1_team_patch(update_team_input, opts = {}) ⇒ GetPublicTeamResponse
Update team Updates mutable team profile fields (name, emoji, URL, email).
-
#api_v1_team_patch_with_http_info(update_team_input, opts = {}) ⇒ Array<(GetPublicTeamResponse, Integer, Hash)>
Update team Updates mutable team profile fields (name, emoji, URL, email).
-
#initialize(api_client = ApiClient.default) ⇒ TeamsApi
constructor
A new instance of TeamsApi.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/emailguard_sdk/api/teams_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#api_v1_team_get(opts = {}) ⇒ GetPublicTeamResponse
Get team Returns profile fields for the team associated with your API key.
26 27 28 29 |
# File 'lib/emailguard_sdk/api/teams_api.rb', line 26 def api_v1_team_get(opts = {}) data, _status_code, _headers = api_v1_team_get_with_http_info(opts) data end |
#api_v1_team_get_with_http_info(opts = {}) ⇒ Array<(GetPublicTeamResponse, Integer, Hash)>
Get team Returns profile fields for the team associated with your API key.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/emailguard_sdk/api/teams_api.rb', line 35 def api_v1_team_get_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TeamsApi.api_v1_team_get ...' end # resource path local_var_path = '/api/v1/team' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetPublicTeamResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"TeamsApi.api_v1_team_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TeamsApi#api_v1_team_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#api_v1_team_patch(update_team_input, opts = {}) ⇒ GetPublicTeamResponse
Update team
Updates mutable team profile fields (name, emoji, URL, email). Send only the fields you want to change; omitted fields are left unchanged except name, which is required on every request.
84 85 86 87 |
# File 'lib/emailguard_sdk/api/teams_api.rb', line 84 def api_v1_team_patch(update_team_input, opts = {}) data, _status_code, _headers = api_v1_team_patch_with_http_info(update_team_input, opts) data end |
#api_v1_team_patch_with_http_info(update_team_input, opts = {}) ⇒ Array<(GetPublicTeamResponse, Integer, Hash)>
Update team Updates mutable team profile fields (name, emoji, URL, email). Send only the fields you want to change; omitted fields are left unchanged except `name`, which is required on every request.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/emailguard_sdk/api/teams_api.rb', line 94 def api_v1_team_patch_with_http_info(update_team_input, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TeamsApi.api_v1_team_patch ...' end # verify the required parameter 'update_team_input' is set if @api_client.config.client_side_validation && update_team_input.nil? fail ArgumentError, "Missing the required parameter 'update_team_input' when calling TeamsApi.api_v1_team_patch" end # resource path local_var_path = '/api/v1/team' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(update_team_input) # return_type return_type = opts[:debug_return_type] || 'GetPublicTeamResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"TeamsApi.api_v1_team_patch", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TeamsApi#api_v1_team_patch\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |