Class: Emailguard::EmailDetectData
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Emailguard::EmailDetectData
- Defined in:
- lib/emailguard_sdk/models/email_detect_data.rb
Instance Attribute Summary collapse
-
#confidence ⇒ Object
high, medium, or low when a disposable verdict includes a confidence signal.
-
#detection_source ⇒ Object
Returns the value of attribute detection_source.
-
#disposable ⇒ Object
Returns the value of attribute disposable.
-
#disposable_provider ⇒ Object
Returns the value of attribute disposable_provider.
-
#domain ⇒ Object
Returns the value of attribute domain.
-
#email ⇒ Object
Returns the value of attribute email.
-
#evidence ⇒ Object
Returns the value of attribute evidence.
-
#normalized ⇒ Object
Returns the value of attribute normalized.
-
#public_domain ⇒ Object
Returns the value of attribute public_domain.
-
#relay_domain ⇒ Object
Returns the value of attribute relay_domain.
-
#relay_provider ⇒ Object
Returns the value of attribute relay_provider.
-
#role_address ⇒ Object
Returns the value of attribute role_address.
-
#subaddressing ⇒ Object
Returns the value of attribute subaddressing.
-
#suggested_domain ⇒ Object
Corrected domain candidate when a domain or TLD typo rule matches.
-
#suggested_email ⇒ Object
Corrected email candidate when a domain or TLD typo rule matches.
-
#syntax_validation ⇒ Object
Returns the value of attribute syntax_validation.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EmailDetectData
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ EmailDetectData
Initializes the object
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/emailguard_sdk/models/email_detect_data.rb', line 115 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Emailguard::EmailDetectData` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Emailguard::EmailDetectData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'confidence') self.confidence = attributes[:'confidence'] end if attributes.key?(:'detection_source') self.detection_source = attributes[:'detection_source'] end if attributes.key?(:'disposable') self.disposable = attributes[:'disposable'] end if attributes.key?(:'disposable_provider') self.disposable_provider = attributes[:'disposable_provider'] end if attributes.key?(:'domain') self.domain = attributes[:'domain'] end if attributes.key?(:'email') self.email = attributes[:'email'] end if attributes.key?(:'evidence') self.evidence = attributes[:'evidence'] end if attributes.key?(:'normalized') self.normalized = attributes[:'normalized'] end if attributes.key?(:'public_domain') self.public_domain = attributes[:'public_domain'] end if attributes.key?(:'relay_domain') self.relay_domain = attributes[:'relay_domain'] end if attributes.key?(:'relay_provider') self.relay_provider = attributes[:'relay_provider'] end if attributes.key?(:'role_address') self.role_address = attributes[:'role_address'] end if attributes.key?(:'subaddressing') self.subaddressing = attributes[:'subaddressing'] end if attributes.key?(:'suggested_domain') self.suggested_domain = attributes[:'suggested_domain'] end if attributes.key?(:'suggested_email') self.suggested_email = attributes[:'suggested_email'] end if attributes.key?(:'syntax_validation') self.syntax_validation = attributes[:'syntax_validation'] end end |
Instance Attribute Details
#confidence ⇒ Object
high, medium, or low when a disposable verdict includes a confidence signal.
19 20 21 |
# File 'lib/emailguard_sdk/models/email_detect_data.rb', line 19 def confidence @confidence end |
#detection_source ⇒ Object
Returns the value of attribute detection_source.
21 22 23 |
# File 'lib/emailguard_sdk/models/email_detect_data.rb', line 21 def detection_source @detection_source end |
#disposable ⇒ Object
Returns the value of attribute disposable.
23 24 25 |
# File 'lib/emailguard_sdk/models/email_detect_data.rb', line 23 def disposable @disposable end |
#disposable_provider ⇒ Object
Returns the value of attribute disposable_provider.
25 26 27 |
# File 'lib/emailguard_sdk/models/email_detect_data.rb', line 25 def disposable_provider @disposable_provider end |
#domain ⇒ Object
Returns the value of attribute domain.
27 28 29 |
# File 'lib/emailguard_sdk/models/email_detect_data.rb', line 27 def domain @domain end |
#email ⇒ Object
Returns the value of attribute email.
29 30 31 |
# File 'lib/emailguard_sdk/models/email_detect_data.rb', line 29 def email @email end |
#evidence ⇒ Object
Returns the value of attribute evidence.
31 32 33 |
# File 'lib/emailguard_sdk/models/email_detect_data.rb', line 31 def evidence @evidence end |
#normalized ⇒ Object
Returns the value of attribute normalized.
33 34 35 |
# File 'lib/emailguard_sdk/models/email_detect_data.rb', line 33 def normalized @normalized end |
#public_domain ⇒ Object
Returns the value of attribute public_domain.
35 36 37 |
# File 'lib/emailguard_sdk/models/email_detect_data.rb', line 35 def public_domain @public_domain end |
#relay_domain ⇒ Object
Returns the value of attribute relay_domain.
37 38 39 |
# File 'lib/emailguard_sdk/models/email_detect_data.rb', line 37 def relay_domain @relay_domain end |
#relay_provider ⇒ Object
Returns the value of attribute relay_provider.
39 40 41 |
# File 'lib/emailguard_sdk/models/email_detect_data.rb', line 39 def relay_provider @relay_provider end |
#role_address ⇒ Object
Returns the value of attribute role_address.
41 42 43 |
# File 'lib/emailguard_sdk/models/email_detect_data.rb', line 41 def role_address @role_address end |
#subaddressing ⇒ Object
Returns the value of attribute subaddressing.
43 44 45 |
# File 'lib/emailguard_sdk/models/email_detect_data.rb', line 43 def subaddressing @subaddressing end |
#suggested_domain ⇒ Object
Corrected domain candidate when a domain or TLD typo rule matches.
46 47 48 |
# File 'lib/emailguard_sdk/models/email_detect_data.rb', line 46 def suggested_domain @suggested_domain end |
#suggested_email ⇒ Object
Corrected email candidate when a domain or TLD typo rule matches.
49 50 51 |
# File 'lib/emailguard_sdk/models/email_detect_data.rb', line 49 def suggested_email @suggested_email end |
#syntax_validation ⇒ Object
Returns the value of attribute syntax_validation.
51 52 53 |
# File 'lib/emailguard_sdk/models/email_detect_data.rb', line 51 def syntax_validation @syntax_validation end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
76 77 78 |
# File 'lib/emailguard_sdk/models/email_detect_data.rb', line 76 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
81 82 83 |
# File 'lib/emailguard_sdk/models/email_detect_data.rb', line 81 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/emailguard_sdk/models/email_detect_data.rb', line 54 def self.attribute_map { :'confidence' => :'confidence', :'detection_source' => :'detection_source', :'disposable' => :'disposable', :'disposable_provider' => :'disposable_provider', :'domain' => :'domain', :'email' => :'email', :'evidence' => :'evidence', :'normalized' => :'normalized', :'public_domain' => :'public_domain', :'relay_domain' => :'relay_domain', :'relay_provider' => :'relay_provider', :'role_address' => :'role_address', :'subaddressing' => :'subaddressing', :'suggested_domain' => :'suggested_domain', :'suggested_email' => :'suggested_email', :'syntax_validation' => :'syntax_validation' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 |
# File 'lib/emailguard_sdk/models/email_detect_data.rb', line 247 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
108 109 110 111 |
# File 'lib/emailguard_sdk/models/email_detect_data.rb', line 108 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/emailguard_sdk/models/email_detect_data.rb', line 86 def self.openapi_types { :'confidence' => :'String', :'detection_source' => :'String', :'disposable' => :'Boolean', :'disposable_provider' => :'String', :'domain' => :'String', :'email' => :'String', :'evidence' => :'EmailDetectEvidence', :'normalized' => :'String', :'public_domain' => :'Boolean', :'relay_domain' => :'Boolean', :'relay_provider' => :'String', :'role_address' => :'Boolean', :'subaddressing' => :'Boolean', :'suggested_domain' => :'String', :'suggested_email' => :'String', :'syntax_validation' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/emailguard_sdk/models/email_detect_data.rb', line 211 def ==(o) return true if self.equal?(o) self.class == o.class && confidence == o.confidence && detection_source == o.detection_source && disposable == o.disposable && disposable_provider == o.disposable_provider && domain == o.domain && email == o.email && evidence == o.evidence && normalized == o.normalized && public_domain == o.public_domain && relay_domain == o.relay_domain && relay_provider == o.relay_provider && role_address == o.role_address && subaddressing == o.subaddressing && suggested_domain == o.suggested_domain && suggested_email == o.suggested_email && syntax_validation == o.syntax_validation end |
#eql?(o) ⇒ Boolean
234 235 236 |
# File 'lib/emailguard_sdk/models/email_detect_data.rb', line 234 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
240 241 242 |
# File 'lib/emailguard_sdk/models/email_detect_data.rb', line 240 def hash [confidence, detection_source, disposable, disposable_provider, domain, email, evidence, normalized, public_domain, relay_domain, relay_provider, role_address, subaddressing, suggested_domain, suggested_email, syntax_validation].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
196 197 198 199 200 |
# File 'lib/emailguard_sdk/models/email_detect_data.rb', line 196 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/emailguard_sdk/models/email_detect_data.rb', line 269 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
204 205 206 207 |
# File 'lib/emailguard_sdk/models/email_detect_data.rb', line 204 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |