Class: Emailguard::NotificationRuleResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Emailguard::NotificationRuleResponse
- Defined in:
- lib/emailguard_sdk/models/notification_rule_response.rb
Instance Attribute Summary collapse
-
#channels ⇒ Object
Channel targets notified when the rule matches.
-
#conditions ⇒ Object
Optional conditions (e.g. usage threshold percents).
-
#created_at ⇒ Object
When the rule was created (RFC3339).
-
#description ⇒ Object
Optional longer description.
-
#event_types ⇒ Object
Event types that trigger this rule.
-
#id ⇒ Object
Rule record ID.
-
#is_enabled ⇒ Object
Whether the rule is actively delivering events.
-
#name ⇒ Object
Display name for the rule.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NotificationRuleResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ NotificationRuleResponse
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/emailguard_sdk/models/notification_rule_response.rb', line 88 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Emailguard::NotificationRuleResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Emailguard::NotificationRuleResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'channels') if (value = attributes[:'channels']).is_a?(Array) self.channels = value end end if attributes.key?(:'conditions') if (value = attributes[:'conditions']).is_a?(Hash) self.conditions = value end end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'event_types') if (value = attributes[:'event_types']).is_a?(Array) self.event_types = value end end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'is_enabled') self.is_enabled = attributes[:'is_enabled'] end if attributes.key?(:'name') self.name = attributes[:'name'] end end |
Instance Attribute Details
#channels ⇒ Object
Channel targets notified when the rule matches.
19 20 21 |
# File 'lib/emailguard_sdk/models/notification_rule_response.rb', line 19 def channels @channels end |
#conditions ⇒ Object
Optional conditions (e.g. usage threshold percents).
22 23 24 |
# File 'lib/emailguard_sdk/models/notification_rule_response.rb', line 22 def conditions @conditions end |
#created_at ⇒ Object
When the rule was created (RFC3339).
25 26 27 |
# File 'lib/emailguard_sdk/models/notification_rule_response.rb', line 25 def created_at @created_at end |
#description ⇒ Object
Optional longer description.
28 29 30 |
# File 'lib/emailguard_sdk/models/notification_rule_response.rb', line 28 def description @description end |
#event_types ⇒ Object
Event types that trigger this rule.
31 32 33 |
# File 'lib/emailguard_sdk/models/notification_rule_response.rb', line 31 def event_types @event_types end |
#id ⇒ Object
Rule record ID.
34 35 36 |
# File 'lib/emailguard_sdk/models/notification_rule_response.rb', line 34 def id @id end |
#is_enabled ⇒ Object
Whether the rule is actively delivering events.
37 38 39 |
# File 'lib/emailguard_sdk/models/notification_rule_response.rb', line 37 def is_enabled @is_enabled end |
#name ⇒ Object
Display name for the rule.
40 41 42 |
# File 'lib/emailguard_sdk/models/notification_rule_response.rb', line 40 def name @name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
57 58 59 |
# File 'lib/emailguard_sdk/models/notification_rule_response.rb', line 57 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
62 63 64 |
# File 'lib/emailguard_sdk/models/notification_rule_response.rb', line 62 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/emailguard_sdk/models/notification_rule_response.rb', line 43 def self.attribute_map { :'channels' => :'channels', :'conditions' => :'conditions', :'created_at' => :'created_at', :'description' => :'description', :'event_types' => :'event_types', :'id' => :'id', :'is_enabled' => :'is_enabled', :'name' => :'name' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/emailguard_sdk/models/notification_rule_response.rb', line 186 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 |
# File 'lib/emailguard_sdk/models/notification_rule_response.rb', line 81 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/emailguard_sdk/models/notification_rule_response.rb', line 67 def self.openapi_types { :'channels' => :'Array<NotificationRuleChannelResponse>', :'conditions' => :'Hash<String, Object>', :'created_at' => :'String', :'description' => :'String', :'event_types' => :'Array<String>', :'id' => :'String', :'is_enabled' => :'Boolean', :'name' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/emailguard_sdk/models/notification_rule_response.rb', line 158 def ==(o) return true if self.equal?(o) self.class == o.class && channels == o.channels && conditions == o.conditions && created_at == o.created_at && description == o.description && event_types == o.event_types && id == o.id && is_enabled == o.is_enabled && name == o.name end |
#eql?(o) ⇒ Boolean
173 174 175 |
# File 'lib/emailguard_sdk/models/notification_rule_response.rb', line 173 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
179 180 181 |
# File 'lib/emailguard_sdk/models/notification_rule_response.rb', line 179 def hash [channels, conditions, created_at, description, event_types, id, is_enabled, name].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
143 144 145 146 147 |
# File 'lib/emailguard_sdk/models/notification_rule_response.rb', line 143 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/emailguard_sdk/models/notification_rule_response.rb', line 208 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
151 152 153 154 |
# File 'lib/emailguard_sdk/models/notification_rule_response.rb', line 151 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |